.. application.archiving.rst
.. 
.. Project: AutoArchive
.. License: GNU GPLv3
.. 
.. Copyright (C) 2003 - 2015 Róbert Čerňanský



.. A section for the AutoArchive._application.archiving package.



AutoArchive._application.archiving
==================================

.. automodule:: AutoArchive._application.archiving
   :no-members:



Sub-Packages
------------

.. toctree::
   :maxdepth: 1

   application.archiving.archiver_manipulator



Modules
-------

archiving_application
^^^^^^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._application.archiving.archiving_application



config_constants
^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._application.archiving.config_constants



_archiving
^^^^^^^^^^

.. automodule:: AutoArchive._application.archiving._archiving
.. autoclass:: _Archiving



_backup_information_provider
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._application.archiving._backup_information_provider
.. autoclass:: _BackupInformationProvider



_command_executor
^^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._application.archiving._command_executor
.. autoclass:: _CommandExecutor



_archiving_constants
^^^^^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._application.archiving._archiving_constants
.. autoclass:: _ArchiverMaps
.. autoclass:: _RestartStorageVariables



_archive_spec
^^^^^^^^^^^^^

.. automodule:: AutoArchive._application.archiving._archive_spec
.. autoclass:: _ArchiveSpec
.. autoclass:: _ArchiveSpecOptions



_archive_info
^^^^^^^^^^^^^

.. automodule:: AutoArchive._application.archiving._archive_info
.. autoclass:: _ArchiveInfo
.. autoclass:: _BackupLevelRestartReasons
